@@ -13,12 +13,16 @@ from ssh_proxy_server.interfaces import (
     BaseServerInterface,
     ServerInterface
 )
-from ssh_proxy_server.forwarders import (
-    BaseForwarder,
+from ssh_proxy_server.forwarders.base import BaseForwarder
+from ssh_proxy_server.forwarders.scp import (
     SCPBaseForwarder,
-    SCPForwarder,
+    SCPForwarder
+)
+from ssh_proxy_server.forwarders.ssh import (
     SSHBaseForwarder,
-    SSHForwarder,
+    SSHForwarder
+)
+from ssh_proxy_server.forwarders.sftp import (
     SFTPHandlerBasePlugin,
     SFTPHandlerPlugin
 )
@@ -42,6 +46,12 @@ def main():
         type=int,
         help='listen port'
     )
+    parser.add_argument(
+        '--transparent',
+        dest='transparent',
+        action='store_true',
+        help='enables transparent mode (requires root)'
+    )
     parser.add_argument(
         '--host-key',
         dest='host_key',
@@ -105,7 +115,8 @@ def main():
         scp_interface=args.scp_interface,
         sftp_handler=args.sftp_handler,
         authentication_interface=args.auth_interface,
-        authenticator=args.authenticator
+        authenticator=args.authenticator,
+        transparent=args.transparent
     )
     if args.banner_name is not None:
         Transport._CLIENT_ID = args.banner_name
